==> haskell-data-dword-0.3.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-dword
version: 0.3.1.2
id: data-dword-0.3.1.2-DRHyKbnztlbJO1utR7QYjW
key: data-dword-0.3.1.2-DRHyKbnztlbJO1utR7QYjW
license: BSD3
copyright: 2011-2018 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-dword
synopsis: Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.DoubleWord Data.DoubleWord.TH
hidden-modules: Data.DoubleWord.Base
abi: 096c167e10db03b998264ef1c02057a2
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-dword-0.3.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-dword-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-dword-0.3.1.2
hs-libraries: HSdata-dword-0.3.1.2-DRHyKbnztlbJO1utR7QYjW
depends:
    base-4.10.1.0 hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    data-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o template-haskell-2.12.0.0
    ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             data-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o=489ccc47bb58cc09ab39cf342ed52ffa
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html: /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.1.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-dword
version: 0.3.1.2
id: data-dword-0.3.1.2-FhSVSZ7o1eU5ohGg6Jh0kj
key: data-dword-0.3.1.2-FhSVSZ7o1eU5ohGg6Jh0kj
license: BSD3
copyright: 2011-2018 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-dword
synopsis: Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.
category: Data
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Data.DoubleWord Data.DoubleWord.TH
hidden-modules: Data.DoubleWord.Base
abi: 5deb8bc7ab08bc704f5509dd74196057
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/data-dword-0.3.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/data-dword-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/data-dword-0.3.1.2
hs-libraries: HSdata-dword-0.3.1.2-FhSVSZ7o1eU5ohGg6Jh0kj
depends:
    base-4.10.1.0 hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    data-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o template-haskell-2.12.0.0
    ghc-prim-0.5.1.1
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             data-bword-0.1.0.1-7zvfJtZFNGfCahDd33151o=489ccc47bb58cc09ab39cf342ed52ffa
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
haddock-interfaces: /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html: /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
